@@ -1,7 +1,7 @@
 package Plack::Response;
 use strict;
 use warnings;
-our $VERSION = '0.9978';
+our $VERSION = '0.9979';
 $VERSION = eval $VERSION;
 
 use Plack::Util::Accessor qw(body status);
@@ -271,6 +271,13 @@ B<does not> convert string formats such as C<+3M>.
       expires => time + 24 * 60 * 60,
   };
 
+=item finalize
+
+  $res->finalize;
+
+Returns the status code, headers, and body of this response as a PSGI
+response array reference.
+
 =back
 
 =head1 AUTHOR
